patch_app library

Classes

PatchApp
A helper class that manages Shorebird code push updates and restarts.
PatchAppScope
A widget that registers PatchApp for the wrapped subtree.

Enums

PatchResult
Represents the outcome of a patch update attempt.

Functions

patchAppConfirmationDialog({required BuildContext context, String title = 'Restart to Update', String content = 'A new update is available.\n\n' 'Would you like to restart the app to apply the update?', String cancelLabel = 'CANCEL', String restartLabel = 'RESTART', bool useRootNavigator = true, bool isForce = false}) Future<bool>
Displays a confirmation dialog to the user asking if they want to restart the app to apply an update.