patchAppConfirmationDialog({requiredBuildContextcontext, Stringtitle = 'Restart to Update', Stringcontent = 'A new update is available.\n\n' 'Would you like to restart the app to apply the update?', StringcancelLabel = 'CANCEL', StringrestartLabel = 'RESTART', booluseRootNavigator = true, boolisForce = false})
→ Future<bool>
Displays a confirmation dialog to the user asking if they want to
restart the app to apply an update.